Package 'HiCocietyExample'

Title: Example HiC and Two 'HiCociety' Outputs for Demonstration and Testing
Description: Provides an example HiC dataset and two examples of 'HiCociety' outputs from a function named hic2community(). The data are intended for demonstration purposes only and kept small enough to be distributed via CRAN.
Authors: Sora Yoon [aut, cre]
Maintainer: Sora Yoon <[email protected]>
License: MIT + file LICENSE
Version: 1.0.0
Built: 2026-06-07 08:58:28 UTC
Source: https://github.com/cran/HiCocietyExample

Help Index


Example HiC data file path

Description

Example HiC data file path

Usage

get_example_hic_path()

Value

The file path to the example HiC data.

Examples

get_example_hic_path()

Example HiCociety object for naive CD4+ T cells of mice

Description

Example HiCociety object for naive CD4+ T cells of mice

Usage

get_example_HiCociety_obj_mouse_naiveCD4T()

Value

The HiCociety object for the naive CD4+ T cells of mice.

Examples

get_example_HiCociety_obj_mouse_naiveCD4T()

Example HiCociety object for Th1 cells of mice

Description

Example HiCociety object for Th1 cells of mice

Usage

get_example_HiCociety_obj_mouse_Th1()

Value

The HiCociety object for the Th1 cells of mice.