Welcome to ClientVPS Mirrors

Help for package HiCocietyExample
Type: Package
Title: Example HiC and Two 'HiCociety' Outputs for Demonstration and Testing
Version: 1.0.0
Maintainer: Sora Yoon <sora.yoon@pennmedicine.upenn.edu>
Description: Provides an example HiC dataset and two examples of 'HiCociety' outputs from a function named hic2community(). The data are intended for demonstration purposes only and kept small enough to be distributed via CRAN.
Depends: R (≥ 3.5.0)
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-04-15 18:06:48 UTC; sora
Author: Sora Yoon [aut, cre]
Repository: CRAN
Date/Publication: 2025-04-22 14:10:06 UTC

Example HiCociety object for Th1 cells of mice

Description

Example HiCociety object for Th1 cells of mice

Usage

get_example_HiCociety_obj_mouse_Th1()

Value

The HiCociety object for the Th1 cells of mice.


Example HiCociety object for naive CD4+ T cells of mice

Description

Example HiCociety object for naive CD4+ T cells of mice

Usage

get_example_HiCociety_obj_mouse_naiveCD4T()

Value

The HiCociety object for the naive CD4+ T cells of mice.

Examples

get_example_HiCociety_obj_mouse_naiveCD4T()

Example HiC data file path

Description

Example HiC data file path

Usage

get_example_hic_path()

Value

The file path to the example HiC data.

Examples

get_example_hic_path()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.