| Title: | Example HiC and Two 'HiCociety' Outputs for Demonstration and Testing |
|---|---|
| Description: | Provides an example HiC dataset and two examples of 'HiCociety' outputs from a function named hic2community(). The data are intended for demonstration purposes only and kept small enough to be distributed via CRAN. |
| Authors: | Sora Yoon [aut, cre] |
| Maintainer: | Sora Yoon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-06-07 08:58:28 UTC |
| Source: | https://github.com/cran/HiCocietyExample |
Example HiC data file path
get_example_hic_path()get_example_hic_path()
The file path to the example HiC data.
get_example_hic_path()get_example_hic_path()
Example HiCociety object for naive CD4+ T cells of mice
get_example_HiCociety_obj_mouse_naiveCD4T()get_example_HiCociety_obj_mouse_naiveCD4T()
The HiCociety object for the naive CD4+ T cells of mice.
get_example_HiCociety_obj_mouse_naiveCD4T()get_example_HiCociety_obj_mouse_naiveCD4T()
Example HiCociety object for Th1 cells of mice
get_example_HiCociety_obj_mouse_Th1()get_example_HiCociety_obj_mouse_Th1()
The HiCociety object for the Th1 cells of mice.